
<h1 align="center">
  QMVVM
</h1>
<p align="center">
  A Model-View-ViewModel(MVVM) framework for Qt
</p>

<div align="center">

[![Version](https://img.shields.io/pypi/v/QMVVM?color=%2334D058&label=Version)](https://pypi.org/project/QMVVM)
[![Apache v2.0](https://img.shields.io/badge/License-Apache%20v2.0-blue?color=#4ec820)](LICENSE)
[![Platform Win32 | Linux | macOS](https://img.shields.io/badge/Platform-Win32%20|%20Linux%20|%20macOS-blue?color=#4ec820)]()

</div>

<p align="center">
English | <a href="docs/README_zh.md">简体中文</a>
</p>


## Install
To install using pip:
```shell
pip install qmvvm
```

## Run Example
After installing QMVVM package using pip, you can run any demo in the example directory:
```shell
cd example
python demo.py
```

## License
QMVVM is licensed under [Apache v2.0](./LICENSE).

Copyright © 2025 by zhiyiYo.